codestare namespace
===================

Some of the utility / functionality used to implement the Ubi Interact Framework is rather generic and
therefore developed as part of a different module, :mod:`codestare.async_utils`.


.. py:module:: codestare

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   codestare.async_utils
